Command-Line Interface Reference
================================

Users can interact with designate using the Openstack client via the
commands provided by the `designate plugin`_

Information on the commands available through Designate's Command Line
Interface (CLI) can be found in this section.


.. toctree::
   :maxdepth: 1

   designate-manage
   designate-status

.. _designate plugin: https://docs.openstack.org/python-openstackclient/latest/cli/plugin-commands/designate.html
